@@ -24,6 +24,26 @@ class MockApiClient(object):
         self.responses.append((request, response))
         return (request, response)
 
+    def add_error_response(
+        self,
+        operation_id: str,
+        status_code: int,
+        title="Mock error response",
+        content="Mock error response",
+        body=None,
+        *args,
+        **kwargs,
+    ):
+        """Store a new mock error response for a request on an endpoint"""
+        request = MockRequest(operation_id, body, args, kwargs)
+        error = apistar.exceptions.ErrorResponse(
+            title=title,
+            status_code=status_code,
+            content=content,
+        )
+        self.responses.append((request, error))
+        return (request, error)
+
     def next_response(self, request: MockRequest):
         """Find the next available response for a request, and remove it from the stack"""
         for request_cmp, response in self.responses:
@@ -46,6 +66,8 @@ class MockApiClient(object):
         response = next(self.next_response(request), None)
         if response is not None:
             logger.info(f"Sending mock response for {operation_id}")
+            if isinstance(response, Exception):
+                raise response
             return response
 
         # Throw exception when no response is found
